@@ -271,6 +271,6 @@ def pull_json_data(document_json):
         
         return dirpath, validate
     else:
-        raise Exception('Require valid fields for populate JSON are not present!')
+        raise Exception("ERROR: Failed to clone the remote repository, check the connection configuration in %s connector. " % connector)
 
     return dirpath, False
\ No newline at end of file
